==> nextcloud-30.0.13.tgz: nextcloud/apps/weather_status/l10n/fr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresse inconnue",
    "No result." : "Aucun résultat",
    "Malformed JSON data." : "Données JSON mal formées.",
    "Error" : "Erreur",
    "Weather status" : "Statut météo",
    "Weather status in your dashboard" : "Statut météo sur votre tableau de bord",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Conditions météo intégrées à l’app Tableau de bord.\nLa position géographique peut être déterminée automatiquement ou définie manuellement. Une prévision à 6 heures est ensuite affichée.\nLa météo peut également être intégrée à d’autres emplacements comme l’app Calendrier.",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Ciel dégagé dans la journée",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Ciel dégagé",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Nuageux dans la journée",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nuageux",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} neige et tonnerre plus tard dans la journée",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} neige et tonnerre",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} averses de neige et tonnerre plus tard dans la journée",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} averses de neige et tonnerre",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} averses de neige, tonnerre et crépuscule polaire plus tard dans la journée",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} averses de neige, tonnerre et crépuscule polaire",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} averses de neige plus tard dans la journée",
    "{temperature} {unit} snow showers" : "{temperature} {unit} averses de neige",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} averses de neige et crépuscule polaire plus tard dans la journée",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} averses de neige et crépuscule polaire",
    "{temperature} {unit} snow later today" : "{temperature} {unit} neige plus tard dans la journée",
    "{temperature} {unit} snow" : "{temperature} {unit} neige",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Beau temps dans la journée",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Beau temps",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Partiellement nuageux dans la journée",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Partiellement nuageux",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Brouillard dans la journée",
    "{temperature} {unit} foggy" : "{temperature} {unit} Brouillard",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} Pluie légère dans la journée",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} Pluie légère",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} Pluie dans la journée",
    "{temperature} {unit} rainfall" : "{temperature} {unit} Pluie",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} Fortes pluies dans la journée",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} Fortes pluies",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} Averses dans la journée",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} Averses",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} Faibles averses dans la journée",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} Faibles averses",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} Fortes averses dans la journée",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} Fortes averses",
    "More weather for {adr}" : "Plus de météo pour {adr}",
    "Loading weather" : "Chargement de la météo",
    "Set location for weather" : "Définir l'emplacement pour la météo",
    "Remove from favorites" : "Retirer des favoris",
    "Add as favorite" : "Ajouter comme favori",
    "You are not logged in." : "Vous n'êtes pas connecté.",
    "There was an error getting the weather status information." : "Une erreur s'est produite lors de l'obtention des informations sur l'état de la météo.",
    "No weather information found" : "Aucune information météo",
    "Location not found" : "Lieu non trouvé",
    "There was an error setting the location address." : "Une erreur s'est produite lors de la définition de l'adresse de l'emplacement.",
    "There was an error setting the location." : "Une erreur s'est produite lors de la définition de l'emplacement.",
    "There was an error saving the mode." : "Une erreur s'est produite lors de l'enregistrement du mode.",
    "There was an error using personal address." : "Une erreur s'est produite lors de l'utilisation de l'adresse personnelle.",
    "Unknown weather code" : "Code météo inconnu",
    "Detect location" : "Détecter la position",
    "Set custom address" : "Définir une adresse personnalisée",
    "Favorites" : "Favoris"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.13.tgz: nextcloud/apps/weather_status/l10n/fr.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresse inconnue",
    "No result." : "Aucun résultat",
    "Malformed JSON data." : "Données JSON mal formées.",
    "Error" : "Erreur",
    "Weather status" : "Statut météo",
    "Weather status in your dashboard" : "Statut météo sur votre tableau de bord",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Conditions météo intégrées à l’app Tableau de bord.\nLa position géographique peut être déterminée automatiquement ou définie manuellement. Une prévision à 6 heures est ensuite affichée.\nLa météo peut également être intégrée à d’autres emplacements comme l’app Calendrier.",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Ciel dégagé dans la journée",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Ciel dégagé",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Nuageux dans la journée",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nuageux",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} neige et tonnerre plus tard dans la journée",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} neige et tonnerre",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} averses de neige et tonnerre plus tard dans la journée",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} averses de neige et tonnerre",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} averses de neige, tonnerre et crépuscule polaire plus tard dans la journée",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} averses de neige, tonnerre et crépuscule polaire",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} averses de neige plus tard dans la journée",
    "{temperature} {unit} snow showers" : "{temperature} {unit} averses de neige",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} averses de neige et crépuscule polaire plus tard dans la journée",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} averses de neige et crépuscule polaire",
    "{temperature} {unit} snow later today" : "{temperature} {unit} neige plus tard dans la journée",
    "{temperature} {unit} snow" : "{temperature} {unit} neige",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Beau temps dans la journée",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Beau temps",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Partiellement nuageux dans la journée",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Partiellement nuageux",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Brouillard dans la journée",
    "{temperature} {unit} foggy" : "{temperature} {unit} Brouillard",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} Pluie légère dans la journée",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} Pluie légère",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} Pluie dans la journée",
    "{temperature} {unit} rainfall" : "{temperature} {unit} Pluie",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} Fortes pluies dans la journée",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} Fortes pluies",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} Averses dans la journée",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} Averses",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} Faibles averses dans la journée",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} Faibles averses",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} Fortes averses dans la journée",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} Fortes averses",
    "More weather for {adr}" : "Plus de météo pour {adr}",
    "Loading weather" : "Chargement de la météo",
    "Set location for weather" : "Définir l'emplacement pour la météo",
    "Remove from favorites" : "Retirer des favoris",
    "Add as favorite" : "Ajouter comme favori",
    "You are not logged in." : "Vous n'êtes pas connecté·e.",
    "There was an error getting the weather status information." : "Une erreur est survenue lors de l'obtention des informations météorologiques.",
    "No weather information found" : "Aucune information météo",
    "Location not found" : "Lieu non trouvé",
    "There was an error setting the location address." : "Une erreur est survenue lors de la définition de l'adresse de localisation",
    "There was an error setting the location." : "Une erreur est survenue lors de la définition de l'emplacement.",
    "There was an error saving the mode." : "Une erreur est survenue lors de l'enregistrement du mode.",
    "There was an error using personal address." : "Une erreur est survenue lors de l'utilisation de l'adresse personnelle.",
    "Unknown weather code" : "Code météo inconnu",
    "Detect location" : "Détecter la position",
    "Set custom address" : "Définir une adresse personnalisée",
    "Favorites" : "Favoris"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
